@@ -41,7 +41,7 @@ extern "C" {
 /*
  * EIFFEL_CHECK_LEVEL - this defines the various levels of checking.
  *
- *   See pg 133 of "Eiffel: the language" by Bertrand Meyer.
+ *   See page 133 of "Eiffel: the language" by Bertrand Meyer.
  */
 
 typedef enum { 
@@ -55,7 +55,7 @@ typedef enum {
 
 /*
  * EIFFEL_CHECK - the level of checking to be done for this compile.
- *   This can be overridden by -DEIFFEL_CHECK=CHECK_ALL
+ *   This can be overridden, e.g. by compiling with -DEIFFEL_CHECK=CHECK_ALL
  */
 
 #ifndef EIFFEL_CHECK
@@ -63,18 +63,55 @@ typedef enum {
 #endif
 
 /*
- * invariant() - each class using this library should provide a
- *   method called invariant() which returns true if the object
- *   is consistent, false otherwise. This method will be called 
- *   by REQUIRE and ENSURE if EIFFEL_CHECK is set high enough.
- *   Since some people don't use class invariants we will define 
- *   a default one which always succeeds.
+ * invariant() - each class using this library should provide a method
+ *   called invariant() which returns true if the object is
+ *   consistent, false otherwise. This method will be called by the
+ *   checking macros below.  Since some classes don't have class
+ *   invariants we will define a default one which always succeeds.  
  */
 
 static inline bool invariant() {
   return true;
 }
 
+/*
+ * EIFFEL_DOEND - if EIFFEL_DOEND is defined then (at the suggestion
+ *   of Bertrand Meyer (Eiffel's author)) we define the DO and END 
+ *   macros which check the class invariant on method entry/exit. To
+ *   use these macros your methods should look something like:
+ *
+ *   // if EIFFEL_DOEND is defined
+ *   void Stack::push(int n) 
+ *   DO 
+ *      REQUIRE(..) ; // note this is optional
+ *      .. 
+ *      if(x >= 10) { 
+ *        ...
+ *	}
+ *   END
+ *
+ *   if EIFFEL_DOEND is not defined then we revert to the old
+ *   behaviour where invariants are checked by REQUIRE and ENSURE 
+ *   calls. For example:
+ *
+ *   // if EIFFEL_DOEND is not defined
+ *   void Stack::push(int n) 
+ *   {
+ *      REQUIRE(x <= 10); // note this is required if you 
+ *      ...               // wish to check invariants
+ *      ENSURE(...);
+ *   }
+ */
+
+#ifdef EIFFEL_DOEND
+
+#define DO  { IG(invariant(), EIFFEL_CHECK >= CHECK_INVARIANT); 
+#define END  IG(invariant(), EIFFEL_CHECK >= CHECK_INVARIANT); }
+#define REQUIRE(e) IG(e, EIFFEL_CHECK >= CHECK_REQUIRE)
+#define ENSURE(e) IG(e, EIFFEL_CHECK >= CHECK_ENSURE)
+
+#else /*!defined EIFFEL_DOEND */
+
 /*
  * REQUIRE(e) - precondition for a method, this also checks the class
  *   invariant. 
@@ -97,6 +134,8 @@ static inline bool invariant() {
     IG(invariant(), EIFFEL_CHECK >= CHECK_INVARIANT); \
   } while(0)
 
+#endif /* defined EIFFEL_DOEND */
+
 /*
  * CHECK(e) - check an assertion in inline code.
  */
