@@ -25,7 +25,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: L_times.c,v 1.1.1.1 1997/11/23 11:45:50 pjm Exp $
+ * $Id: L_times.c,v 1.2 1998/07/03 03:25:31 pjm Exp $
  */
 
 #include <stdio.h>
@@ -40,12 +40,12 @@ main() {
   double t = 1.0; 
 
 
-  printf("* L_times - testing L_times buffer\n");
-  printf("** L_times_create(10)\n");
+  printf("** L_times - testing L_times buffer\n");
+  printf("*** L_times_create(10)\n");
   p = L_times_create(10);
-  printf("** Empty buffer\n");
+  printf("*** dump empty buffer\n");
   L_times_dump(p,stdout);
-  printf("** Add one message\n");
+  printf("*** Add one message\n");
   L_times_add(p, "Reactor is too hot", t+= 0.1);
   L_times_dump(p,stdout);
   printf("** Add 100 messages and dump\n");
